complete -c acme-redirect -n "__fish_use_subcommand" -s c -l config -r
complete -c acme-redirect -n "__fish_use_subcommand" -l config-dir -r
complete -c acme-redirect -n "__fish_use_subcommand" -l chall-dir -r
complete -c acme-redirect -n "__fish_use_subcommand" -l data-dir -r
complete -c acme-redirect -n "__fish_use_subcommand" -l acme-url -r
complete -c acme-redirect -n "__fish_use_subcommand" -l acme-email -r
complete -c acme-redirect -n "__fish_use_subcommand" -s v -l verbose -d 'Verbose logging output (Can be set multiple times)'
complete -c acme-redirect -n "__fish_use_subcommand" -s q -l quiet -d 'Silent output (except errors)'
complete -c acme-redirect -n "__fish_use_subcommand" -s h -l help -d 'Print help information'
complete -c acme-redirect -n "__fish_use_subcommand" -f -a "daemon" -d 'Run the redirect daemon'
complete -c acme-redirect -n "__fish_use_subcommand" -f -a "status" -d 'Show the status of our certificates'
complete -c acme-redirect -n "__fish_use_subcommand" -f -a "renew" -d 'Request new certificates if needed'
complete -c acme-redirect -n "__fish_use_subcommand" -f -a "check" -d 'Check if the challenges could be completed'
complete -c acme-redirect -n "__fish_use_subcommand" -f -a "dump-config" -d 'Load the configuration and dump it to stdout as json'
complete -c acme-redirect -n "__fish_use_subcommand" -f -a "completions" -d 'Generate shell completions'
complete -c acme-redirect -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c acme-redirect -n "__fish_seen_subcommand_from daemon" -s B -l bind-addr -d 'The address to listen on' -r
complete -c acme-redirect -n "__fish_seen_subcommand_from daemon" -l user -d 'Drop from root to this user' -r
complete -c acme-redirect -n "__fish_seen_subcommand_from daemon" -l chroot -d 'Chroot into the challenge directory'
complete -c acme-redirect -n "__fish_seen_subcommand_from daemon" -s v -l verbose -d 'Verbose logging output (Can be set multiple times)'
complete -c acme-redirect -n "__fish_seen_subcommand_from daemon" -s q -l quiet -d 'Silent output (except errors)'
complete -c acme-redirect -n "__fish_seen_subcommand_from daemon" -s h -l help -d 'Print help information'
complete -c acme-redirect -n "__fish_seen_subcommand_from status" -s v -l verbose -d 'Verbose logging output (Can be set multiple times)'
complete -c acme-redirect -n "__fish_seen_subcommand_from status" -s q -l quiet -d 'Silent output (except errors)'
complete -c acme-redirect -n "__fish_seen_subcommand_from status" -s h -l help -d 'Print help information'
complete -c acme-redirect -n "__fish_seen_subcommand_from renew" -s n -l dry-run -d 'Do not actually do anything, just show what would happen'
complete -c acme-redirect -n "__fish_seen_subcommand_from renew" -l force-renew -d 'Renew certificates even if they are not about to expire'
complete -c acme-redirect -n "__fish_seen_subcommand_from renew" -l skip-restarts -d 'Do not execute the configured exec commands'
complete -c acme-redirect -n "__fish_seen_subcommand_from renew" -l skip-cleanup -d 'Don\'t clean up old certs that are not live anymore'
complete -c acme-redirect -n "__fish_seen_subcommand_from renew" -l hooks-only -d 'Only execute hooks without actually renewing certs'
complete -c acme-redirect -n "__fish_seen_subcommand_from renew" -s v -l verbose -d 'Verbose logging output (Can be set multiple times)'
complete -c acme-redirect -n "__fish_seen_subcommand_from renew" -s q -l quiet -d 'Silent output (except errors)'
complete -c acme-redirect -n "__fish_seen_subcommand_from renew" -s h -l help -d 'Print help information'
complete -c acme-redirect -n "__fish_seen_subcommand_from check" -s v -l verbose -d 'Verbose logging output (Can be set multiple times)'
complete -c acme-redirect -n "__fish_seen_subcommand_from check" -s q -l quiet -d 'Silent output (except errors)'
complete -c acme-redirect -n "__fish_seen_subcommand_from check" -s h -l help -d 'Print help information'
complete -c acme-redirect -n "__fish_seen_subcommand_from dump-config" -s v -l verbose -d 'Verbose logging output (Can be set multiple times)'
complete -c acme-redirect -n "__fish_seen_subcommand_from dump-config" -s q -l quiet -d 'Silent output (except errors)'
complete -c acme-redirect -n "__fish_seen_subcommand_from dump-config" -s h -l help -d 'Print help information'
complete -c acme-redirect -n "__fish_seen_subcommand_from completions" -s v -l verbose -d 'Verbose logging output (Can be set multiple times)'
complete -c acme-redirect -n "__fish_seen_subcommand_from completions" -s q -l quiet -d 'Silent output (except errors)'
complete -c acme-redirect -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Print help information'
complete -c acme-redirect -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from daemon; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from renew; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from dump-config; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "daemon" -d 'Run the redirect daemon'
complete -c acme-redirect -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from daemon; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from renew; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from dump-config; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "status" -d 'Show the status of our certificates'
complete -c acme-redirect -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from daemon; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from renew; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from dump-config; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "renew" -d 'Request new certificates if needed'
complete -c acme-redirect -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from daemon; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from renew; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from dump-config; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "check" -d 'Check if the challenges could be completed'
complete -c acme-redirect -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from daemon; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from renew; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from dump-config; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "dump-config" -d 'Load the configuration and dump it to stdout as json'
complete -c acme-redirect -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from daemon; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from renew; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from dump-config; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "completions" -d 'Generate shell completions'
complete -c acme-redirect -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from daemon; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from renew; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from dump-config; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
